@@ -7,4 +7,4 @@ def mont_nimba():
 	argv = sys.argv
 	path_app = pathlib.Path(__file__).parent.absolute()
 	utility = CommandUtility(path_app, argv)
-	utility.execute()
\ No newline at end of file
+	utility()
\ No newline at end of file
